@@ -5,7 +5,6 @@ import os
 import shutil
 from os.path import basename as _path_basename
 from pathlib import Path
-from platform import system as _platform_system
 from shlex import quote
 from time import sleep as time_sleep
 from typing import List, Optional, Tuple
@@ -20,7 +19,6 @@ SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / 'sound'
 ASSET_DIR_IN_SYS = Path(Path.home(), '.config', 'exclock')
 CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / 'clock'))).absolute()
 SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / 'sound'))).absolute()
-PLATFORM = _platform_system()
 
 
 def executable(cmd: str) -> bool:
@@ -167,7 +165,7 @@ def notify(title: str, message: str) -> None:
 
 
 @contract(lambda spend_sec: spend_sec >= 0)
-def notify_all_term(
+def notify_all(
     title: str,
     message: str,
     spend_sec: int,
